using DiskCardGame;
using InscryptionAPI.Card;
using GBC;
using System.Collections;
using UnityEngine;

namespace CoolMod;

public partial class Plugin
{
    private void Add_Cartographer()
    {
        Texture2D tex = Asset.LoadTexture("ExplorererPixel.png");
        Sprite texSprite1 = Sprite.Create(tex, new Rect(0.0f, 0.0f, tex.width, tex.height), new Vector2(0.5f, 0.5f), 100.0f);

        AbilityInfo explorer = AbilityManager.New(
        PluginGuid,
        "Explorer",
        "pay four bones to draw cards equal to the amount of different temples on your side of the board.",
        typeof(Explorer),
        Asset.LoadTexture("Explorer.png")
    );
        explorer.pixelIcon = texSprite1;
        explorer.powerLevel = 4;
        explorer.activated = true;

        Explorer.ability = explorer.ability;

        CardInfo cardInfo = CardManager.New(modPrefix: PluginGuid2, "Cartographer", "Cartographer", 1, 2, "Mapping out the lands, revealing hidden knowledge through exploration.")
            .SetDefaultPart3Card()
            .SetPortrait(Asset.LoadTexture("portrait_Cartographer.png"))
            .SetEmissivePortrait(Asset.LoadTexture("CartographerEmission.png"))
            .AddAbilities(explorer.ability)
            .SetPixelPortrait(Asset.LoadTexture("Cartographer.png"))
            .SetGBCPlayable(CardTemple.Undead)
            .SetBonesCost(4)
            ;
        CardManager.Add("arackulele.inscryption.grimoramod", cardInfo);
    }
    public class Explorer : ExtendedActivatedAbilityBehaviour
    {
        internal static Ability ability;
        public override Ability Ability => ability;
        public override int StartingBonesCost => 4;
        public override bool CanActivate() => true;
        public override IEnumerator Activate()
        {
            bool nature = false;
            bool undead = false;
            bool tech = false;
            bool wizard = false;
            for (int i = 0; i < BoardManager.Instance.playerSlots.Count; i++)
            {
                yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + " scaled the horizons!", TextBox.Style.Neutral);
                if (BoardManager.Instance.playerSlots[i].Card != null)
                {
                    if (BoardManager.Instance.playerSlots[i].Card.Info.temple == CardTemple.Nature)
                    {
                        Debug.Log("nature");
                        nature = true;
                    }
                    if (BoardManager.Instance.playerSlots[i].Card.Info.temple == CardTemple.Undead)
                    {
                        Debug.Log("undead");
                        undead = true;
                    }
                    if (BoardManager.Instance.playerSlots[i].Card.Info.temple == CardTemple.Wizard)
                    {
                        Debug.Log("wizard");
                        wizard = true;
                    }
                    if (BoardManager.Instance.playerSlots[i].Card.Info.temple == CardTemple.Tech)
                    {
                        Debug.Log("tech");
                        tech = true;
                    }
                }
            }
            if (nature) { 
                Debug.Log("nature draw");
                yield return Singleton<CardDrawPiles>.Instance.DrawCardFromDeck();
                nature = false;
            }
            if (undead) { 
                Debug.Log("undead draw");
                yield return Singleton<CardDrawPiles>.Instance.DrawCardFromDeck();
                undead = false;
            }
            if (wizard) { 
                Debug.Log("wizard draw");
                yield return Singleton<CardDrawPiles>.Instance.DrawCardFromDeck();
                wizard = false;
            }
            if (tech) { 
                Debug.Log("tech draw");
                yield return Singleton<CardDrawPiles>.Instance.DrawCardFromDeck();
                tech = false;
            }
            yield break;
        }
    }
}