using DiskCardGame;
using GBC;
using InscryptionAPI.Card;
using InscryptionAPI.Triggers;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

namespace CoolMod;

public partial class Plugin
{
    private void Add_DavyJones()
    {
        StatIconInfo shanty = StatIconManager.New("Shanty", "Entomophagia", "the value reperesented with this sigil will be equal to the amount of anchored cards on the field.", typeof(Shanty))
            .SetDefaultPart1Ability()
            .SetIcon(Asset.LoadTexture("Entomophagia.png"))
            .SetPixelIcon(Asset.LoadTexture("olcrew2.png"));
        shanty.appliesToAttack = true;
        shanty.appliesToHealth = false;
        shanty.gbcDescription = "the power of [creature] is equal to the amount of anchored cards you control.";

        AbilityInfo anchor = AbilityManager.New(PluginGuid, "Anchor", $"[creature] cannot be pushed out of its original slot.", typeof(Anchor), "VesselBuff.png")
            .SetPixelAbilityIcon(Asset.LoadTexture("pixelsigilanchored.png"))
            ;
        AbilityInfo crossbones = AbilityManager.New(PluginGuid, "Crossbones", $"at the end of your turn, [creature] steals 1 energy and stores it up to 4. when it dies, it returns twice that many bones.", typeof(Crossboned), "VesselBuff.png")
            .SetPixelAbilityIcon(Asset.LoadTexture("pixelsoultobones.png"))
            ;
        Anchor.ability = anchor.ability;
        Crossboned.ability = crossbones.ability;

        CardManager.New(modPrefix: PluginGuid2, "DavyJones", "Davy Jones", 0, 3, "")
            .SetPortrait(Asset.LoadTexture("PylonZapper.png"))
            .SetEmissivePortrait(Asset.LoadTexture("PylonZapper.png"))
            .AddAbilities(Anchor.ability)
            .SetPixelPortrait(Asset.LoadTexture("davyjones.png"))
            .SetStatIcon(shanty.iconType)
            .SetGBCPlayable(CardTemple.Undead)
            .SetBonesCost(3)
            .SetRare()
            ;
        CardManager.New(modPrefix: PluginGuid, "Crossbones", "Crossbones", 0, 2, "")
            .SetPortrait(Asset.LoadTexture("PylonZapper.png"))
            .SetEmissivePortrait(Asset.LoadTexture("PylonZapper.png"))
            .AddAbilities(Crossboned.ability, Anchor.ability)
            .SetPixelPortrait(Asset.LoadTexture("crossbones.png"))
            .SetGBCPlayable(CardTemple.Undead)
            .SetBonesCost(1)
            ;

    }
    public class Crossboned : AbilityBehaviour
    {
        internal static Ability ability;
        public override Ability Ability => ability;
        int bones = 0;
        public override bool RespondsToUpkeep(bool playerUpkeep)
        {
            if (!playerUpkeep)
            {
                return true;
            }
            else
            {
                return false;
            }
        }
        public override bool RespondsToDie(bool wasSacrifice, PlayableCard killer) => true;
        public override IEnumerator OnUpkeep(bool playerUpkeep)
        {
            if (Singleton<ResourcesManager>.Instance.PlayerEnergy > 0)
            {
                if (bones < 4)
                {
                    bones++;
                    yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + " steals an energy cell, and stores it within. (x" + bones + ")", TextBox.Style.Neutral);
                    yield return Singleton<ResourcesManager>.Instance.SpendEnergy(1);
                }
            }
            else
            {
                yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + " has no energy to steal.", TextBox.Style.Neutral);
                Card.Anim.NegationEffect(true);
            }
            yield return base.OnUpkeep(playerUpkeep);
        }
        public override IEnumerator OnDie(bool wasSacrifice, PlayableCard killer)
        {
            yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + "  burst into " + bones * 2 + " bones!", TextBox.Style.Neutral);
            yield return Singleton<ResourcesManager>.Instance.AddBones(bones * 2);
            yield return base.OnDie(wasSacrifice, killer);
        }
    }
    public class Anchor : AbilityBehaviour
    {
        internal static Ability ability;
        public override Ability Ability => ability;
        public CardSlot startslot = null;
        public override bool RespondsToOtherCardAssignedToSlot(PlayableCard otherCard) => true;
        public override bool RespondsToResolveOnBoard() => true;
        bool replayed = false;
        public override IEnumerator OnOtherCardAssignedToSlot(PlayableCard otherCard)
        {
            if (otherCard.slot == startslot && otherCard != Card)
            {
                Debug.Log("push");
                yield return Singleton<TextBox>.Instance.ShowUntilInput("...but a true pirate never loses ground!", TextBox.Style.Neutral);
                yield return BoardManager.Instance.AssignCardToSlot(otherCard, BoardManager.Instance.GetAdjacent(startslot, false), 0.1f);
                yield return new WaitForSeconds(0.2f);
                yield return BoardManager.Instance.AssignCardToSlot(Card, startslot, 0.1f);
            }
            yield return base.OnOtherCardAssignedToSlot(otherCard);
        }
        public override IEnumerator OnResolveOnBoard()
        {
            if (!replayed)
            {
                startslot = Card.slot;
                replayed = true;
            }
            return base.OnResolveOnBoard();
        }
    }

    public class Shanty : VariableStatBehaviour
    {
        int x = 0;
        public override SpecialStatIcon IconType => SpecialStatIcon.Ants;
        public override bool RespondsToResolveOnBoard() => true;
        public override bool RespondsToOtherCardResolve(PlayableCard otherCard) => true;
        public override bool RespondsToOtherCardDie(PlayableCard card, CardSlot deathSlot, bool fromCombat, PlayableCard killer) => true;
        public override IEnumerator OnResolveOnBoard()
        {
            for (int i = 0; i < BoardManager.Instance.allSlots.Count; i++)
            {
                if (BoardManager.Instance.allSlots[i].Card != null)
                {
                    if (BoardManager.Instance.allSlots[i].Card.HasAbility(Anchor.ability))
                    {
                        x++;
                    }
                }
            }
            return base.OnResolveOnBoard();
        }
        public override int[] GetStatValues()
        {
            int[] array = new int[2];
            array[0] = x - 1;
            return array;
        }
        public override IEnumerator OnOtherCardResolve(PlayableCard otherCard)
        {
            if (otherCard.HasAbility(Anchor.ability) && otherCard.IsPlayerCard())
            {
                x++;
            }
            return base.OnOtherCardResolve(otherCard);
        }
        public override IEnumerator OnOtherCardDie(PlayableCard card, CardSlot deathSlot, bool fromCombat, PlayableCard killer)
        {
            if (card.HasAbility(Anchor.ability) && card.IsPlayerCard())
            {
                x--;
            }
            return base.OnOtherCardDie(card, deathSlot, fromCombat, killer);
        }
    }
}