using DiskCardGame;
using GBC;
using HarmonyLib;
using InscryptionAPI.Card;
using System;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

namespace CoolMod;

public partial class Plugin
{
    public readonly static SpecialTriggeredAbility PortraitChecker = SpecialTriggeredAbilityManager.Add(PluginGuid, "PortraitCheck", typeof(ShieldPortrait)).Id;
    private void Add_GemGuard()
    {
        AbilityInfo gemguarded = AbilityManager.New(PluginGuid, "Gem Guardian", $"when [creature] is played, all gems are given the armored sigil.", typeof(ShieldGems), "GemGuardianPixel.png")
         .SetPixelAbilityIcon(Asset.LoadTexture("GemGuardianPixel.png"))
         ;
        AbilityInfo Looters = AbilityManager.New(PluginGuid, "Looter", $"if a creature opposes [creature], it's sigils are negated.", typeof(LootersDraw), "ability_Looter.png")
        .SetPixelAbilityIcon(Asset.LoadTexture("looter.png"));
        LootersDraw.ability = Looters.ability;
        AbilityInfo SentrySubmerges = AbilityManager.New(PluginGuid, "Sentry", $"When a creature moves into the space opposite this card, they take 1 damage.", typeof(SentrySubmerge), "ability_sentry.png")
        .SetPixelAbilityIcon(Asset.LoadTexture("pixelability_sentry.png"));
        SentrySubmerge.ability = SentrySubmerges.ability;


        CardManager.New(modPrefix: PluginGuid3, "GemGuardian", "Gem Guardian", 0, 1, "")
            .SetDefaultPart3Card()
            .SetPortrait(Asset.LoadTexture("portrait_fire.png"))
            .SetEmissivePortrait(Asset.LoadTexture("portrait_fire.png"))
            .AddAbilities(gemguarded.ability)
            .SetPixelPortrait(Asset.LoadTexture("GemGuard.png"))
            .SetGBCPlayable(CardTemple.Wizard)
            .SetCost(gemsCost: new List<GemType> { GemType.Orange })
            ;
        CardManager.BaseGameCards.CardByName("MoxRuby").AddSpecialAbilities(PortraitChecker);
        CardManager.BaseGameCards.CardByName("MoxSapphire").AddSpecialAbilities(PortraitChecker);
        CardManager.BaseGameCards.CardByName("MoxEmerald").AddSpecialAbilities(PortraitChecker);
    }
    private void Add_GemBomb()
    {
        CardManager.New(modPrefix: PluginGuid3, "GemBomb", "Gem Detonator", 0, 1, "When [creature] is played, all Gems on your side of the field gain armor")
            .SetDefaultPart3Card()
            .SetPortrait(Asset.LoadTexture("portrait_fire.png"))
            .SetEmissivePortrait(Asset.LoadTexture("portrait_fire.png"))
            .AddAbilities(Ability.ExplodeGems)
            .SetPixelPortrait(Asset.LoadTexture("GemDet.png"))
            .SetGBCPlayable(CardTemple.Wizard)
            .SetCost(gemsCost: new List<GemType> { GemType.Blue })
            ;
    }
    public class ShieldGems : AbilityBehaviour
    {
        internal static Ability ability;
        public override Ability Ability => ability;
        public override bool RespondsToOtherCardResolve(PlayableCard otherCard) => true;
        public override bool RespondsToResolveOnBoard() => true;
        public override IEnumerator OnOtherCardResolve(PlayableCard otherCard)
        {
            if (otherCard.HasTrait(Trait.Gem))
            {
                if (Singleton<TextBox>.Instance != null)
                {
                    yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + " guarded " + otherCard.Info.displayedName + "!", TextBox.Style.Neutral);
                }
                otherCard.AddTemporaryMod(Shield);
            }
            yield return base.OnOtherCardResolve(otherCard);
        }
        public override IEnumerator OnResolveOnBoard()
        {
            for (int i = 0; i < BoardManager.Instance.playerSlots.Count; i++)
            {
                if (BoardManager.Instance.playerSlots[i].Card != null)
                {
                    if (BoardManager.Instance.playerSlots[i].Card.Info.HasTrait(Trait.Gem) && BoardManager.Instance.playerSlots[i].Card.LacksAbility(Ability.DeathShield))
                    {

                        if (Singleton<TextBox>.Instance != null)
                        {
                            yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + " guarded your gems!", TextBox.Style.Neutral);
                        }
                            BoardManager.Instance.playerSlots[i].Card.AddTemporaryMod(Shield);

                    }
                    if (BoardManager.Instance.playerSlots[i].Card.Info.HasTrait(Trait.Gem) && BoardManager.Instance.playerSlots[i].Card.LacksAbility(Ability.DeathShield))
                    {
                        if (Singleton<TextBox>.Instance != null)
                        {
                            yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + " guarded your gems!", TextBox.Style.Neutral);
                        }
                        BoardManager.Instance.playerSlots[i].Card.AddTemporaryMod(Shield);

                    }
                }
            }
            yield return base.OnResolveOnBoard();
        }
        public CardModificationInfo Shield
        {
            get
            {
                CardModificationInfo info = new CardModificationInfo() { abilities = new List<Ability>() };
                CardModificationInfo blankinfo = new CardModificationInfo() { abilities = new List<Ability>() };
                if (info.LacksAbility(Ability.DeathShield))
                {
                    info.AddAbilities(Ability.DeathShield);
                    return info;
                }
                return blankinfo;
            }
        }
    }
    public class ShieldPortrait : SpecialCardBehaviour
    {

    }
    public class LootersDraw : AbilityBehaviour
    {
        internal static Ability ability;
        public override Ability Ability => ability;
        public override bool RespondsToDealDamageDirectly(int amount) => true;
        public override IEnumerator OnDealDamageDirectly(int amount)
        {
            for (int i = 0; i < amount; i++)
            {
                yield return Singleton<CardDrawPiles>.Instance.DrawCardFromDeck();

            }
            bool drawPile3DIsActive = CardDrawPiles3D.Instance && CardDrawPiles3D.Instance.pile;
            if (amount > 0)
            {
                yield return new WaitForSeconds(0.75f);
                ViewManager.Instance.SwitchToView(View.CardPiles, lockAfter: true);
                yield return new WaitForSeconds(0.5f);
            }
            for (int i = 0; i < amount; i++)
            {
                if (drawPile3DIsActive)
                {
                    CardDrawPiles3D.Instance.pile.Draw();
                }
            }

        }
    }
    public class SentrySubmerge : ExtendedAbilityBehaviour
    {
        internal static Ability ability;
        public override Ability Ability => Ability;
        public override bool ShouldTriggerWhenFaceDown(Trigger trigger, object[] otherArgs) => true;
        public override bool RespondsToOtherCardAssignedToSlot(PlayableCard otherCard) => true;
        public override IEnumerator OnOtherCardAssignedToSlot(PlayableCard otherCard)
        {
            if (otherCard.slot == Card.OpposingSlot())
            {
                if (Singleton<TextBox>.Instance != null)
                {
                    yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + " takes a free shot.", TextBox.Style.Neutral);
                }
                Card.Anim.PlayAttackAnimation(false, Card.OpposingSlot());
                yield return otherCard.TakeDamage(1, Card);
            }
            yield return base.OnOtherCardAssignedToSlot(otherCard);
        }
    }
}