using DiskCardGame;
using GBC;
using InscryptionAPI.Card;
using InscryptionAPI.Triggers;
using System.Collections;
using UnityEngine;

namespace CoolMod;

public partial class Plugin
{
    private void Add_GeoLocusts()
    {
        AbilityInfo geophage = AbilityManager.New(PluginGuid, "Geophagia", $"When [creature] is played, destroy all cards that are unable to be sacrificed, this cards power stat is equal to the amount of cards destroyed", typeof(Geophagia), "Geophagia.png")
        .SetPixelAbilityIcon(Asset.LoadTexture("GeophagiaPixel.png"))
        .SetDefaultPart1Ability()
        ;
        CardManager.New(modPrefix: PluginGuid, "GeoLocusts", "Geo Locusts", 0, 2, "The ravenous locusts, a would-be bringer of plague, if it werent for their diet.")
            .SetDefaultPart1Card()
            .SetPortrait(Asset.LoadTexture("GeoLocusts.png"))
            .SetEmissivePortrait(Asset.LoadTexture("GeoLocustsEmission.png"))
            .AddAbilities(geophage.ability)
            .SetPixelPortrait(Asset.LoadTexture("GemLocusts.png"))
            .SetGBCPlayable(CardTemple.Nature)
            .SetBloodCost(2)
            .AddTribes(Tribe.Insect)
            ;
    }
    public class Geophagia : AbilityBehaviour, IPassiveAttackBuff
    {
        public override Ability Ability => Ability;
        int damage = 0;
        public override bool RespondsToResolveOnBoard() => true;
        public override IEnumerator OnResolveOnBoard()
        {
            if (Singleton<TextBox>.Instance != null)
            {
                yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + " ate through the terrain!", TextBox.Style.Neutral);
            }

            {
                for(int i = 0; i < BoardManager.Instance.playerSlots.Count; i++)
                {
                    if (BoardManager.Instance.playerSlots[i].Card != null)
                    {
                        if (BoardManager.Instance.playerSlots[i].Card.HasTrait(Trait.Terrain))
                        {
                            yield return BoardManager.Instance.playerSlots[i].Card.Die(false, null, true);
                            damage++;
                        }
                    }
                }
                for (int i = 0; i < BoardManager.Instance.opponentSlots.Count; i++)
                {
                    if (BoardManager.Instance.opponentSlots[i].Card != null)
                    {
                        if (BoardManager.Instance.opponentSlots[i].Card.HasTrait(Trait.Terrain))
                        {
                            yield return BoardManager.Instance.opponentSlots[i].Card.Die(false, null, true);
                            damage++;
                        }
                    }
                }
                Debug.Log(damage);
                yield return base.OnResolveOnBoard();
            }
        }
        public int GetPassiveAttackBuff(PlayableCard target) => Card.OnBoard && target == Card ? damage : 0;
    }
}