using DiskCardGame;
using GBC;
using HarmonyLib;
using InscryptionAPI.Card;
using InscryptionAPI.Triggers;
using System.Collections;
using UnityEngine;

namespace CoolMod;

public partial class Plugin
{
    private void Add_Grandma()
    {
        CardInfo cardInfo = CardManager.New(modPrefix: PluginGuid2, "GrimoraMod_Grandma", "Grandma", 0, 2, "A helpful grandma to dig up more bones.")
            .SetPortrait(Asset.LoadTexture("Grandma.png"))
            .SetEmissivePortrait(Asset.LoadTexture("GrandmaEmission.png"))
            .AddAbilities(Ability.Transformer, Ability.BoneDigger)
            .SetPixelPortrait(Asset.LoadTexture("GrandmaPixel.png"))
            .SetGBCPlayable(CardTemple.Undead)
            .AddMetaCategories(CardMetaCategory.GBCPack, CardMetaCategory.GBCPlayable)
            .SetEvolve($"{PluginGuid}_Wrinkler", 1)
            .AddMetaCategories(CardMetaCategory.GBCPack)
            .SetBonesCost(2);
        ;
        CardManager.Add("arackulele.inscryption.grimoramod", cardInfo);
    }
    private void Add_Wrinkler()
    {
        AbilityInfo bloodsuck = AbilityManager.New(PluginGuid2, "BloodGuzzler", $"When [creature] deals damage, it gains 1 health for each damage dealt.", typeof(BloodSucker), "ability_bloodguzzler.png")
        .SetPixelAbilityIcon(Asset.LoadTexture("RockCandyPixel.png"))
        ;
        bloodsuck.rulebookName = "Blood Guzzler";
        bloodsuck.SetPixelAbilityIcon(Asset.LoadTexture("BloodGuzzlerPixel.png"));

        CardManager.New(modPrefix: PluginGuid, "Wrinkler", "Wrinkler", 1, 2, "")
            .SetPortrait(Asset.LoadTexture("Wrinkler.png"))
            .SetEmissivePortrait(Asset.LoadTexture("WrinklerEmission.png"))
            .AddAbilities(Ability.Transformer, bloodsuck.ability)
            .SetPixelPortrait(Asset.LoadTexture("WrinklerPixel.png"))
            .SetBonesCost(2)
            .SetEvolve($"{PluginGuid}_Grandma", 1)
        ;
    }
    public void AppendTransform()
    {
        AbilityManager.BaseGameAbilities.AbilityByID(Ability.Transformer).Info.SetPixelAbilityIcon(Asset.LoadTexture("TransformerPixel.png"));
    }
    public void AppendRules()
    {
        AbilityManager.BaseGameAbilities.AbilityByID(Ability.ShieldGems).Info.rulebookDescription = "When [creature] is played, all Gems on your side of the field gain armor";
        AbilityManager.BaseGameAbilities.AbilityByID(Ability.Transformer).Info.rulebookDescription = "at the end of your turn, [creature] will switch between forms.";
        AbilityManager.BaseGameAbilities.AbilityByID(Ability.ExplodeGems).Info.rulebookDescription = "When Gems on your side of the field die, they detonate (the creature opposing them, as well as adjacent friendly creatures, are dealt 10 damage)";

    }
    public void AppendBloodsucker()
    {


        AbilityManager.BaseGameAbilities.AbilityByID(Ability.BloodGuzzler).Info.SetPixelAbilityIcon(Asset.LoadTexture("BloodGuzzlerPixel.png"));
        AbilityManager.BaseGameAbilities.AbilityByID(Ability.BloodGuzzler).Info.rulebookDescription = "When [creature] deals damage, it gains 1 health for each damage dealt.";
    }
    public class BloodSucker : AbilityBehaviour
    {
        internal static Ability ability;
        public override Ability Ability => ability;

        public override bool RespondsToDealDamage(int amount, PlayableCard target) => true;
        public override bool RespondsToDealDamageDirectly(int amount) => true;
        public override bool RespondsToResolveOnBoard() => true;
        public override bool RespondsToOtherCardDie(PlayableCard card, CardSlot deathSlot, bool fromCombat, PlayableCard killer) => true;
        Card deadcard = null;
        public override IEnumerator OnOtherCardDealtDamage(PlayableCard attacker, int amount, PlayableCard target)
        {
            deadcard = target;
            return base.OnOtherCardDealtDamage(attacker, amount, target);
        }
        public override IEnumerator OnResolveOnBoard()
        {
            return base.OnResolveOnBoard();
        }
        public override IEnumerator OnDealDamage(int amount, PlayableCard target)
        {
            yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + " drained the life force of " + deadcard.Info.displayedName + "!", TextBox.Style.Neutral);
            Card.AddTemporaryMod(Heal);
            yield return base.OnDealDamage(amount, target);
        }
        public override IEnumerator OnDealDamageDirectly(int amount)
        {
            yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + " drained the opponent's life force!", TextBox.Style.Neutral);
            Card.AddTemporaryMod(Heal);
            yield return base.OnDealDamageDirectly(amount);
        }
        public CardModificationInfo Heal
        {
            get
            {
                CardModificationInfo info = new CardModificationInfo() { healthAdjustment = 1 };
                return info;
            }
        }
    }
}

