using DiskCardGame;
using InscryptionAPI.Card;
using InscryptionAPI.Triggers;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

namespace CoolMod;

public partial class Plugin
{
    private void Add_MoxMirage()
    {
        AbilityInfo moxify = AbilityManager.New(PluginGuid3, "Moxify", $"If [creature]s owner controls a Ruby Gem [creature]s power is increased, if [creature]s owner controls an Emerald Gem [creature]s health is increased, if [creature]s owner controls a Sapphire Gem [creature] counts as a gem.", typeof(Moxify), "Gemified.png")
        .SetPixelAbilityIcon(Asset.LoadTexture("GemifiedPixel.png"))
        ;

        CardManager.New(modPrefix: PluginGuid, "MoxMirage", "Mox Mirage", 0, 1, "")
            .SetDefaultPart3Card()
            .SetPortrait(Asset.LoadTexture("portrait_fire.png"))
            .SetEmissivePortrait(Asset.LoadTexture("portrait_fire.png"))
            .AddAbilities(Ability.GemDependant, moxify.ability)
            .SetPixelPortrait(Asset.LoadTexture("Mox_Mirage.png"))
            .SetGBCPlayable(CardTemple.Wizard)
            .AddMetaCategories(CardMetaCategory.GBCPack)
            ;
    }
    public class Moxify : AbilityBehaviour, IPassiveAttackBuff, IPassiveHealthBuff
    {
        public override Ability Ability => Ability;
        public override bool RespondsToOtherCardResolve(PlayableCard otherCard) => true;
        public override bool RespondsToOtherCardDie(PlayableCard card, CardSlot deathSlot, bool fromCombat, PlayableCard killer) => true;
        public override bool RespondsToResolveOnBoard() => true;
        public override IEnumerator OnOtherCardDie(PlayableCard card, CardSlot deathSlot, bool fromCombat, PlayableCard killer)
        {
            if (ResourcesManager.Instance.HasGem(GemType.Blue))
            {
                if (Card.LacksTrait(Trait.Gem))
                {
                    Card.Info.AddTraits(Trait.Gem);
                }
            } else
            {
                if (Card.HasTrait(Trait.Gem))
                {
                    Card.Info.SetTraits();
                }
            }
            return base.OnOtherCardDie(card, deathSlot, fromCombat, killer);
        }
        public override IEnumerator OnOtherCardResolve(PlayableCard otherCard)
        {
            if (ResourcesManager.Instance.HasGem(GemType.Blue))
            {
                if (Card.LacksTrait(Trait.Gem))
                {
                    Card.Info.AddTraits(Trait.Gem);
                }
            }
            else
            {
                if (Card.HasTrait(Trait.Gem))
                {
                    Card.Info.SetTraits();
                }
            }
            return base.OnOtherCardResolve(otherCard);
        }
        public override IEnumerator OnResolveOnBoard()
        {
            if (ResourcesManager.Instance.HasGem(GemType.Blue))
            {
                if (Card.LacksTrait(Trait.Gem))
                {
                    Card.Info.AddTraits(Trait.Gem);
                }
            }
            else
            {
                if (Card.HasTrait(Trait.Gem))
                {
                    Card.Info.SetTraits();
                }
            }
            return base.OnResolveOnBoard();
        }
        public int GetPassiveAttackBuff(PlayableCard target) => ResourcesManager.Instance.HasGem(GemType.Orange) && target.Info == Card.Info ? 2 : 0;
        public int GetPassiveHealthBuff(PlayableCard target) => ResourcesManager.Instance.HasGem(GemType.Green) && target.Info == Card.Info ? 1 : 0;
    }
}