using DiskCardGame;
using InscryptionAPI.Card;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

namespace CoolMod;

public partial class Plugin
{
    private void Add_Necronomicon()
    {
        AbilityInfo secondchance = AbilityManager.New(PluginGuid, "Second Chance", $"When a non-skeleton card perishes, play a skeleton in its former spot", typeof(SecondChance), "SecondChance.png")
            .SetPixelAbilityIcon(Asset.LoadTexture("SecondChancePixel.png"))
            ;
        AbilityInfo ontherocks = AbilityManager.New(PluginGuid, "On The Rocks", $"while [creature] is on the field, all gems are frozen within with a mage pupil inside", typeof(OnTheRocks), "ontherocks.png")
            .SetPixelAbilityIcon(Asset.LoadTexture("ontherockspixel.png"))
            ;
        CardInfo cardInfo = CardManager.New(modPrefix: PluginGuid2, "GrimoraMod_Necronomicon", "Necronomicon", 0, 3, " This ancient tomb, perhaps this could return this world to its life.")
            .SetDefaultPart3Card()
            .SetPortrait(Asset.LoadTexture("portrait_Necronomicon.png"))
            .SetEmissivePortrait(Asset.LoadTexture("portrait_Necronomicon_emission.png"))
            .AddAbilities(secondchance.ability)
            .SetPixelPortrait(Asset.LoadTexture("Necronomicon.png"))
            .SetGBCPlayable(CardTemple.Undead)
            .SetBonesCost(6)
            .SetRare()
            ;
        CardManager.Add("arackulele.inscryption.grimoramod", cardInfo);
        CardManager.New(modPrefix: PluginGuid, "Tavernkeep", "Tavernkeep", 0, 1, "")
            .SetDefaultPart3Card()
            .SetPortrait(Asset.LoadTexture("portrait_Necronomicon.png"))
            .SetEmissivePortrait(Asset.LoadTexture("portrait_Necronomicon_emission.png"))
            .AddAbilities(ontherocks.ability)
            .SetPixelPortrait(Asset.LoadTexture("tavernkeep.png"))
            .SetGBCPlayable(CardTemple.Wizard)
            .SetCost(gemsCost: new List<GemType> { GemType.Orange })
            ;
    }
    public class SecondChance : AbilityBehaviour
    {
        public override Ability Ability => Ability;
        public override bool RespondsToOtherCardDie(PlayableCard card, CardSlot deathSlot, bool fromCombat, PlayableCard killer) => true;
        public override IEnumerator OnOtherCardDie(PlayableCard card, CardSlot deathSlot, bool fromCombat, PlayableCard killer)
        {
            if (card.Info.name != CardLoader.GetCardByName("Skeleton").name && Card.OnBoard) {
                Debug.Log("spawn");
                yield return new WaitForSeconds(0.4f);
                yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"Skeleton"), deathSlot);
            } else
            {
                Debug.Log("do not");
            }
            yield return base.OnOtherCardDie(card, deathSlot, fromCombat, killer);
        }
    }
    public class OnTheRocks : AbilityBehaviour
    {
        public override Ability Ability => Ability;
        public override bool RespondsToOtherCardDie(PlayableCard card, CardSlot deathSlot, bool fromCombat, PlayableCard killer) => true;
        public override IEnumerator OnOtherCardDie(PlayableCard card, CardSlot deathSlot, bool fromCombat, PlayableCard killer)
        {
            if (card.Info.HasTrait(Trait.Gem) && Card.OnBoard && card.IsPlayerCard() == Card.IsPlayerCard())
            {
                Debug.Log("spawn");
                yield return new WaitForSeconds(0.4f);
                yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"Pupil"), deathSlot);
            }
            else
            {
                Debug.Log("do not");
            }
            yield return base.OnOtherCardDie(card, deathSlot, fromCombat, killer);
        }
    }
}