using DiskCardGame;
using GBC;
using InscryptionAPI.Card;
using InscryptionAPI.Triggers;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

namespace CoolMod;

public partial class Plugin
{

    private void Add_PylonZapper()
    {

        AbilityInfo pylonzap = AbilityManager.New(PluginGuid, "Vessel Buffer", $"While [creature] is on the field, all vessel cards gain +1 Power", typeof(Pylon), "VesselBuff.png")
            .SetPixelAbilityIcon(Asset.LoadTexture("VesselBuffPixel.png"))
            .SetDefaultPart3Ability()
            ;
        AbilityInfo pylonshield = AbilityManager.New(PluginGuid, "Vessel Shielder", $"When [creature] is played, all vessel cards gain the Armored sigil", typeof(Shielder), "VesselShield.png")
            .SetPixelAbilityIcon(Asset.LoadTexture("VesselShieldPixel.png"))
            .SetDefaultPart3Ability()
            ;
        AbilityInfo pyloncost = AbilityManager.New(PluginGuid, "Vessel Charger", $"When a vessel card is played, draw a card", typeof(CostReduct), "VesselCostPixel.png")
            .SetPixelAbilityIcon(Asset.LoadTexture("VesselCostPixel.png"))
            .SetDefaultPart3Ability()
            ;
        AbilityInfo pylonriot = AbilityManager.New(PluginGuid, "Rioter", $"When [creature] is on the board, all vessels gain the flammable sigil", typeof(Riot), "VesselBurn.png")
            .SetPixelAbilityIcon(Asset.LoadTexture("VesselBurnPixel.png"))
            .SetDefaultPart3Ability()
            ;

        CardManager.New(modPrefix: PluginGuid4, "PylonZapper", "Pylon Zapper", 0, 2, "")
            .SetDefaultPart3Card()
            .SetPortrait(Asset.LoadTexture("PylonZapper.png"))
            .SetEmissivePortrait(Asset.LoadTexture("PylonZapper.png"))
            .AddAbilities(pylonzap.ability)
            .SetPixelPortrait(Asset.LoadTexture("PylonZapperPixel.png"))
            .SetGBCPlayable(CardTemple.Tech)
            .SetEnergyCost(3)
            .AddMetaCategories(WizardRegion)
            ;
        CardManager.New(modPrefix: PluginGuid4, "CargoLoaderProtect", "Cargo Loader", 0, 3, "")
            .SetDefaultPart3Card()
            .SetPortrait(Asset.LoadTexture("CargoLoaderShield.png"))
            .SetEmissivePortrait(Asset.LoadTexture("CargoLoaderShield.png"))
            .AddAbilities(Ability.Transformer, pylonshield.ability)
            .SetPixelPortrait(Asset.LoadTexture("CargoLoaderShieldPixel.png"))
            .SetEvolve($"{PluginGuid}_CargoLoaderBuff", 1)
            .SetGBCPlayable(CardTemple.Tech)
            .SetEnergyCost(3)
            .AddMetaCategories(WizardRegion)
            .AddMetaCategories(CardMetaCategory.Rare)
            ;
        CardManager.New(modPrefix: PluginGuid4, "CargoLoaderBuff", "Cargo Loader", 0, 3, "")
            .SetPortrait(Asset.LoadTexture("CargoLoaderBuff.png"))
            .SetEmissivePortrait(Asset.LoadTexture("CargoLoaderBuff.png"))
            .AddAbilities(Ability.Transformer, pylonzap.ability)
            .SetPixelPortrait(Asset.LoadTexture("CargoBuffer.png"))
            .SetEvolve($"{PluginGuid}_CargoLoaderCost", 1)
            .SetEnergyCost(3)
            .AddMetaCategories(CardMetaCategory.Rare)
            .SetGBCPlayable(CardTemple.Tech)
        ;
        CardManager.New(modPrefix: PluginGuid4, "CargoLoaderCost", "Cargo Loader", 0, 3, "")
            .SetPortrait(Asset.LoadTexture("CargoLoaderCost.png"))
            .SetEmissivePortrait(Asset.LoadTexture("CargoLoaderCost.png"))
            .AddAbilities(Ability.Transformer, pyloncost.ability)
            .SetPixelPortrait(Asset.LoadTexture("CargoLoaderCostPixel.png"))
            .SetEvolve($"{PluginGuid}_CargoLoaderProtect", 1)
            .SetEnergyCost(3)
            .SetDefaultPart3Card()
            .AddMetaCategories(CardMetaCategory.Rare)
            .SetGBCPlayable(CardTemple.Tech)
        ;
        CardManager.New(modPrefix: PluginGuid4, "HullGuard", "Hull Guard", 0, 3, "")
            .SetDefaultPart3Card()
            .SetPortrait(Asset.LoadTexture("HullGuard.png"))
            .SetEmissivePortrait(Asset.LoadTexture("HullGuard.png"))
            .AddAbilities(pylonshield.ability)
            .SetPixelPortrait(Asset.LoadTexture("HullGuard_Pixel.png"))
            .SetEnergyCost(3)
            .SetDefaultPart3Card()
            .SetGBCPlayable(CardTemple.Tech)
            .AddMetaCategories(WizardRegion)
        ;
        CardManager.New(modPrefix: PluginGuid4, "Rioter", "Rioter", 1, 2, "")
            .SetDefaultPart3Card()
            .SetPortrait(Asset.LoadTexture("Rioter.png"))
            .SetEmissivePortrait(Asset.LoadTexture("Rioter.png"))
            .AddAbilities(pylonriot.ability)
            .SetPixelPortrait(Asset.LoadTexture("RioterPixel.png"))
            .SetEnergyCost(3)
            .SetGBCPlayable(CardTemple.Tech)
            .AddMetaCategories(WizardRegion)
        ;

    }
    public class Pylon : AbilityBehaviour, IPassiveAttackBuff
    {
        public override Ability Ability => Ability;
        public int GetPassiveAttackBuff(PlayableCard target) => Card.OnBoard && target.Info.displayedName.Contains("Vessel") && target.IsPlayerCard() && Card.IsPlayerCard() ? 1 : 0;
    }
    public class Shielder : AbilityBehaviour
    {
        internal static Ability ability;
        public override Ability Ability => ability;
        public override bool RespondsToResolveOnBoard() => true;
        public override IEnumerator OnResolveOnBoard()
        {
            List<CardSlot> list = (base.Card.OpponentCard ? Singleton<BoardManager>.Instance.OpponentSlotsCopy : Singleton<BoardManager>.Instance.PlayerSlotsCopy);
            List<CardSlot> validSlots = list.FindAll((CardSlot x) => x.Card != null && x.Card.name.Contains("Vessel"));
            if (validSlots.Count > 0)
            {
                yield return new WaitForSeconds(0.25f);
                base.Card.Anim.LightNegationEffect();
                yield return new WaitForSeconds(0.1f);
                List<PlayableCard> validCards = new List<PlayableCard>();
                validSlots.ForEach(delegate (CardSlot x)
                {
                    validCards.Add(x.Card);
                });
                for (int i = 0; i < validCards.Count; i++)
                {
                    validCards[i].AddTemporaryMod(Shield);
                }

            }
        }
        public CardModificationInfo Shield
        {
            get
            {
                CardModificationInfo info = new CardModificationInfo() { abilities = new List<Ability>() };
                info.AddAbilities(Ability.DeathShield);
                return info;
            }
        }
    }
    public class CostReduct : AbilityBehaviour
    {
        internal static Ability ability;
        public override Ability Ability => ability;
        public override bool RespondsToOtherCardResolve(PlayableCard otherCard) => true;
        public override IEnumerator OnOtherCardResolve(PlayableCard otherCard)
        {
            if (otherCard.Info.displayedName.Contains("Vessel"))
            {
                yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + " drew on the vessel's power!", TextBox.Style.Neutral);
                yield return Singleton<CardDrawPiles>.Instance.DrawCardFromDeck();
                yield return base.OnResolveOnBoard();
            }
            yield break;
        }
    }
    public class Riot : AbilityBehaviour
    {
        internal static Ability ability;
        public override Ability Ability => ability;
        public override bool RespondsToResolveOnBoard() => true;
        public override IEnumerator OnResolveOnBoard()
        {
            List<CardSlot> list = (base.Card.OpponentCard ? Singleton<BoardManager>.Instance.OpponentSlotsCopy : Singleton<BoardManager>.Instance.PlayerSlotsCopy);
            List<CardSlot> validSlots = list.FindAll((CardSlot x) => x.Card != null && x.Card.name.Contains("Vessel"));
            if (validSlots.Count > 0)
            {
                yield return new WaitForSeconds(0.25f);
                base.Card.Anim.LightNegationEffect();
                yield return new WaitForSeconds(0.1f);
                List<PlayableCard> validCards = new List<PlayableCard>();
                validSlots.ForEach(delegate (CardSlot x)
                {
                    validCards.Add(x.Card);
                });
                for (int i = 0; i < validCards.Count; i++)
                {
                    validCards[i].AddTemporaryMod(Shield);
                }

            }
        }
        public CardModificationInfo Shield
        {
            get
            {
                CardModificationInfo info = new CardModificationInfo() { abilities = new List<Ability>() };
                info.AddAbilities(Molotov2.ability);
                return info;
            }
        }
    }
}