using DiskCardGame;
using GBC;
using InscryptionAPI.Card;
using InscryptionAPI.Guid;
using Pixelplacement;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

namespace CoolMod;

public partial class Plugin
{
    public static readonly CardMetaCategory WizardRegion = (CardMetaCategory)GuidManager.GetEnumValue<CardMetaCategory>("zorro.inscryption.infiniscryption.p03kayceerun", "WizardRegionCards");
    public static readonly CardMetaCategory BeastRegion = (CardMetaCategory)GuidManager.GetEnumValue<CardMetaCategory>("zorro.inscryption.infiniscryption.p03kayceerun", "NatureRegionCards");
    public static readonly CardMetaCategory DeathRegion = (CardMetaCategory)GuidManager.GetEnumValue<CardMetaCategory>("zorro.inscryption.infiniscryption.p03kayceerun", "UndeadRegionCards");
    public static readonly CardMetaCategory TechRegion = (CardMetaCategory)GuidManager.GetEnumValue<CardMetaCategory>("zorro.inscryption.infiniscryption.p03kayceerun", "TechRegionCards");
    public static readonly CardMetaCategory CenterRegion = (CardMetaCategory)GuidManager.GetEnumValue<CardMetaCategory>("zorro.inscryption.infiniscryption.p03kayceerun", "NeutralRegionCards");

    public void Add_Molotov()
    {
        AbilityInfo firestarter = AbilityManager.New(PluginGuid, "Flammable", $"When [creature] dies, deal 3 damage to adjacent and opposing cards, then play fire in empty and adjacent opposing spaces", typeof(Molotov2), "Flammable.png")
        .SetPixelAbilityIcon(Asset.LoadTexture("FlammablePixel.png"))
        .SetDefaultPart3Ability()
        .SetDefaultPart1Ability()
        ;
        ;
        firestarter.SetCustomFlippedTexture(Asset.LoadTexture("FlammablePixelFlipped.png"));
        Molotov2.ability = firestarter.ability;

        AbilityInfo inversefireman = AbilityManager.New(PluginGuid, "Inverse Fireman", $"When [creature] is played, fill all empty spaces with fire", typeof(InverseFireman), "Inversefireman.png")
        .SetPixelAbilityIcon(Asset.LoadTexture("InversefiremanPixel.png"))
        .SetDefaultPart3Ability()
        .SetDefaultPart1Ability()
        ;
        ;
        InverseFireman.ability = inversefireman.ability;

        CardManager.New(modPrefix: PluginGuid4, "Molotov", "M010T0V", 1, 1, "")
            .SetDefaultPart3Card()
            .SetPortrait(Asset.LoadTexture("M010T0V.png"))
            .SetEmissivePortrait(Asset.LoadTexture("M010T0V.png"))
            .AddAbilities(firestarter.ability)
            .SetPixelPortrait(Asset.LoadTexture("M01010V_Pixel.png"))
            .SetGBCPlayable(CardTemple.Tech)
            .AddMetaCategories(CardMetaCategory.ChoiceNode, CardMetaCategory.TraderOffer, DeathRegion)
            .SetEnergyCost(2);
        ;
        

        CardManager.New(modPrefix: PluginGuid4, "Pyrotechnic", "Pyrotechnic ", 2, 1, "")
            .SetDefaultPart3Card()
            .SetPortrait(Asset.LoadTexture("Pyrotechnic.png"))
            .SetEmissivePortrait(Asset.LoadTexture("Pyrotechnic.png"))
            .AddAbilities(inversefireman.ability)
            .SetPixelPortrait(Asset.LoadTexture("PyrotechnicPixel.png"))
            .SetGBCPlayable(CardTemple.Tech)
            .AddMetaCategories(CardMetaCategory.ChoiceNode, CardMetaCategory.TraderOffer, BeastRegion)
            .SetEnergyCost(4);
        ;
        CardManager.New(modPrefix: PluginGuid4, "Phoenix", "Phoenix", 2, 1, "The effervescent Phoenix, the flame that never goes out.")
            .SetDefaultPart1Card()
            .SetPortrait(Asset.LoadTexture("Pheonix.png"))
            .SetEmissivePortrait(Asset.LoadTexture("PheonixEmission.png"))
            .AddAbilities(inversefireman.ability, Ability.DrawCopyOnDeath)
            .SetPixelPortrait(Asset.LoadTexture("PheonixPixel.png"))
            .SetGBCPlayable(CardTemple.Nature)
            .AddMetaCategories(CardMetaCategory.Rare)
            .SetBloodCost(2)
            .AddTribes(Tribe.Bird)
            .SetRare();
        ;

    }
    public class Molotov2 : AbilityBehaviour
    {
        private const string BOMB_PREFAB_PATH = "Prefabs/Cards/SpecificCardModels/DetonatorHoloBomb";

        private GameObject bombPrefab;

        internal static Ability ability;
        public override Ability Ability => ability;

        private void Awake()
        {
            bombPrefab = ResourceBank.Get<GameObject>("Prefabs/Cards/SpecificCardModels/DetonatorHoloBomb");
        }

        public override bool RespondsToPreDeathAnimation(bool wasSacrifice)
        {
            return base.Card.OnBoard;
        }

        public override IEnumerator OnPreDeathAnimation(bool wasSacrifice)
        {
            if (Singleton<TextBox>.Instance != null)
            {
                yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + " bursts into flames!", TextBox.Style.Neutral);
            }
            base.Card.Anim.LightNegationEffect();
            yield return PreSuccessfulTriggerSequence();
            yield return ExplodeFromSlot(base.Card.Slot);
            yield return LearnAbility(0.25f);
        }

        protected IEnumerator ExplodeFromSlot(CardSlot slot)
        {
            List<CardSlot> adjacentSlots = Singleton<BoardManager>.Instance.GetAdjacentSlots(slot);
            if (adjacentSlots.Count > 0 && adjacentSlots[0].Index < slot.Index)
            {
                if (adjacentSlots[0].Card != null && !adjacentSlots[0].Card.Dead && adjacentSlots[0].Card.Info.displayedName != "Fire")
                {
                    yield return BombCard(adjacentSlots[0].Card, slot.Card);
                }
                adjacentSlots.RemoveAt(0);
            }
            if (slot.opposingSlot.Card != null && !slot.opposingSlot.Card.Dead)
            {
                yield return BombCard(slot.opposingSlot.Card, slot.Card);
            }
            if (adjacentSlots.Count > 0 && adjacentSlots[0].Card != null && !adjacentSlots[0].Card.Dead && adjacentSlots[0].Card.Info.displayedName != "Fire")
            {
                yield return BombCard(adjacentSlots[0].Card, slot.Card);
            }
            yield return new WaitForSeconds(0.3f);
            if (slot.opposingSlot.Card == null)
            {
                yield return PlaceCard(slot.opposingSlot);
            }
            Singleton<ViewManager>.Instance.SwitchToView(View.Board);
            CardSlot toLeft = Singleton<BoardManager>.Instance.GetAdjacent(base.Card.Slot, adjacentOnLeft: true);
            CardSlot toRight = Singleton<BoardManager>.Instance.GetAdjacent(base.Card.Slot, adjacentOnLeft: false);
            bool toLeftValid = toLeft != null && toLeft.Card == null;
            bool toRightValid = toRight != null && toRight.Card == null;
            yield return PreSuccessfulTriggerSequence();
            if (toLeftValid)
            {
                yield return new WaitForSeconds(0.1f);
                yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), toLeft);
            }
            if (toRightValid)
            {
                yield return new WaitForSeconds(0.1f);
                yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), toRight);
            }
            if (toLeftValid || toRightValid)
            {
                yield return LearnAbility();
            }
        }

        private IEnumerator BombCard(PlayableCard target, PlayableCard attacker)
        {
            yield return null;
        }
        private IEnumerator PlaceCard(CardSlot target)
        {
            if (target.Card == null)
            {
                yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), target);
            }
        }
    }

    public class Molotov : AbilityBehaviour
    {
        internal static Ability ability;
        public override Ability Ability => ability;
        public override bool RespondsToDie(bool wasSacrifice, PlayableCard killer) => true;

        public override IEnumerator OnDie(bool wasSacrifice, PlayableCard killer)
        {
            CardSlot up = Card.OpposingSlot();
            CardSlot left = BoardManager.Instance.GetAdjacent(Card.Slot, true);
            CardSlot right = BoardManager.Instance.GetAdjacent(Card.Slot, false);
            yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + " Burst into flames!", TextBox.Style.Neutral);
            if (Card.Slot != BoardManager.Instance.playerSlots[BoardManager.Instance.playerSlots.Count-1])
            {
                if (right.Card != null)
                {
                    if (right.Card.LacksAbility(Ability.Submerge) && right.Card.LacksTrait(Trait.Terrain))
                    {
                        yield return right.Card.TakeDamage(3, null);
                    }
                }
            }
            if (Card.Slot != BoardManager.Instance.playerSlots[0])
            {
                if (left.Card != null)
                {
                    if (left.Card.LacksAbility(Ability.Submerge) && left.Card.LacksTrait(Trait.Terrain))
                    {
                        yield return right.Card.TakeDamage(3, null);
                    }
                }
            }
            if (up.Card != null)
            {
                if (up.Card.LacksAbility(Ability.Submerge) && up.Card.LacksTrait(Trait.Terrain))
                {
                    yield return up.Card.TakeDamage(3, null);
                }
            }
            yield return new WaitForSeconds(0.3f);
            if (right != null)
            {
                if (right.Card == null)
                {
                    yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), right);
                }
            }
            if (left != null)
            {
                if (left.Card == null)
                {
                    yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), left);
                }
            }
            if (up.Card == null)
            {
                yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), up);

            }
            yield return base.OnDie(wasSacrifice, killer);
        }
    }
    public class InverseFireman : AbilityBehaviour
    {
        internal static Ability ability;
        public override Ability Ability => ability;
        public override bool RespondsToResolveOnBoard() => true;
        public override IEnumerator OnResolveOnBoard()
        {
            {
                if (Singleton<TextBox>.Instance != null)
                {
                    yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + "Set the board on fire!", TextBox.Style.Neutral);
                }
                if (BoardManager.Instance.playerSlots[0].Card == null)
                {
                    yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), BoardManager.Instance.playerSlots[0]);
                }
                if (BoardManager.Instance.playerSlots[1].Card == null)
                {
                    yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), BoardManager.Instance.playerSlots[1]);
                }
                if (BoardManager.Instance.playerSlots[2].Card == null)
                {
                    yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), BoardManager.Instance.playerSlots[2]);
                }
                if (BoardManager.Instance.playerSlots[3].Card == null)
                {
                    yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), BoardManager.Instance.playerSlots[3]);
                }
                if (BoardManager.Instance.playerSlots.Count == 5)
                {
                    if (BoardManager.Instance.playerSlots[4].Card == null)
                    {
                        yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), BoardManager.Instance.playerSlots[4]);
                    }
                }
                if (BoardManager.Instance.opponentSlots[0].Card == null)
                {
                    yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), BoardManager.Instance.opponentSlots[0]);
                }
                if (BoardManager.Instance.opponentSlots[1].Card == null)
                {
                    yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), BoardManager.Instance.opponentSlots[1]);
                }
                if (BoardManager.Instance.opponentSlots[2].Card == null)
                {
                    yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), BoardManager.Instance.opponentSlots[2]);
                }
                if (BoardManager.Instance.opponentSlots[3].Card == null)
                {
                    yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), BoardManager.Instance.opponentSlots[3]);
                }
                if (BoardManager.Instance.opponentSlots.Count == 5)
                {
                    if (BoardManager.Instance.opponentSlots[4].Card == null)
                    {
                        yield return BoardManager.Instance.CreateCardInSlot(CardLoader.GetCardByName($"{PluginGuid}_Fire"), BoardManager.Instance.opponentSlots[4]);
                    }
                }
                yield return base.OnResolveOnBoard();
            }
        }
    }

}