using DiskCardGame;
using GBC;
using InscryptionAPI.Card;
using System.Collections;
using System.Collections.Generic;

namespace CoolMod;

public partial class Plugin
{
    private void Add_RollingStone()
    {
        AbilityInfo rollingstone = AbilityManager.New(PluginGuid3, "Rolling", $"A turn after [creature] is played, the opposing card is destroyed, and this moves to its place", typeof(Rolling), "Rolling.png")
            .SetPixelAbilityIcon(Asset.LoadTexture("RollingPixel.png"))
            ;
        Rolling.ability = rollingstone.ability;
        CardManager.New(modPrefix: PluginGuid3, "RollingStone", "Rolling Stone", 0, 1, "")
            .SetDefaultPart3Card()
            .SetPortrait(Asset.LoadTexture("portrait_fire.png"))
            .SetEmissivePortrait(Asset.LoadTexture("portrait_fire.png"))
            .AddAbilities(rollingstone.ability, Ability.GainGemBlue)
            .SetPixelPortrait(Asset.LoadTexture("RollingStone.png"))
            .SetGBCPlayable(CardTemple.Wizard)
            .SetTraits(Trait.Gem, Trait.Terrain)
            .SetCost(gemsCost: new List<GemType> { GemType.Orange })
            ;
    }
    public class Rolling : AbilityBehaviour
    {
        internal static Ability ability;
        public override Ability Ability => ability;
        public override bool RespondsToUpkeep(bool playerUpkeep) => true;
        public override bool RespondsToResolveOnBoard() => true;
        CardSlot slot = null;
        public override IEnumerator OnUpkeep(bool playerUpkeep)
        {
            if (!playerUpkeep && Card.slot == slot)
            {
                if (Card.OpposingSlot().Card != null)
                {
                    yield return Card.OpposingSlot().Card.Die(false);
                }
                yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + " rolled over!", TextBox.Style.Neutral);
                yield return BoardManager.Instance.AssignCardToSlot(Card, Card.OpposingSlot());
                ResourcesManager.Instance.ForceGemsUpdate();
            }
            yield return base.OnUpkeep(playerUpkeep);
        }
        public override IEnumerator OnResolveOnBoard()
        {
            slot = Card.Slot;
            return base.OnResolveOnBoard();
        }
    }
}