using DiskCardGame;
using GBC;
using InscryptionAPI.Card;
using InscryptionAPI.Triggers;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

namespace CoolMod;

public partial class Plugin
{
    private void Add_StarvingDisciple()
    {
        Texture2D tex = Asset.LoadTexture("HungryPixel.png");
        Sprite texSprite1 = Sprite.Create(tex, new Rect(0.0f, 0.0f, tex.width, tex.height), new Vector2(0.5f, 0.5f), 100.0f);

        AbilityInfo hunger = AbilityManager.New(
        PluginGuid,
        "Hungry",
        "sacrifice a creature to add it's stats to [creature]",
        typeof(Starving),
        Asset.LoadTexture("Hungry.png")
    );
        hunger.pixelIcon = texSprite1;
        hunger.powerLevel = 4;
        hunger.activated = true;

        Starving.ability = hunger.ability;

        CardManager.New(modPrefix: PluginGuid3, "StarvingDisciple", "Starving Disciple", 1, 1, "")
            .SetPortrait(Asset.LoadTexture("portrait_Cartographer.png"))
            .SetEmissivePortrait(Asset.LoadTexture("CartographerEmission.png"))
            .AddAbilities(hunger.ability)
            .SetPixelPortrait(Asset.LoadTexture("StarvingDisciple.png"))
            .SetGBCPlayable(CardTemple.Wizard)
            .SetCost(gemsCost: new List<GemType> { GemType.Green })
            .SetRare()
            ;
    }
    public class Starving : ExtendedActivatedAbilityBehaviour, IPassiveHealthBuff, IPassiveAttackBuff
    {
        internal static Ability ability;
        public override Ability Ability => ability;
        public override int StartingBloodCost => 1;
        public override bool CanActivate() => true;
        public override bool RespondsToOtherCardDie(PlayableCard card, CardSlot deathSlot, bool fromCombat, PlayableCard killer) => true;
        int x = 0;
        int y = 0;
        int sacX = 0;
        int sacY = 0;
        string deadcardname = "";
        public override IEnumerator Activate()
        {
            Debug.Log("pressed");
            x += sacX;
            y += sacY;
            yield return Singleton<TextBox>.Instance.ShowUntilInput(Card.Info.displayedName + " Feasted on the flesh of " + deadcardname + "!", TextBox.Style.Neutral);
            Singleton<InteractionCursor>.Instance.ClearForcedCursorType();
            yield break;
        }
        public override IEnumerator OnOtherCardDie(PlayableCard card, CardSlot deathSlot, bool fromCombat, PlayableCard killer)
        {
            sacX = card.Attack;
            sacY = card.Health;
            deadcardname = card.Info.displayedName;
            return base.OnOtherCardDie(card, deathSlot, fromCombat, killer);
        }
        public int GetPassiveAttackBuff(PlayableCard target) => target.Info == Card.Info ? x : 0;
        public int GetPassiveHealthBuff(PlayableCard target) => target.Info == Card.Info ? y : 0;
    }

}
